package com.ruoyi.nanjing.service;

import java.util.List;
import com.ruoyi.nanjing.domain.TRpProductchangeinfo;

/**
 * 机种切换管理Service接口
 * 
 * @author limy
 * @date 2021-01-22
 */
public interface ITRpProductchangeinfoService 
{
    /**
     * 查询机种切换管理
     * 
     * @param ID 机种切换管理ID
     * @return 机种切换管理
     */
    public TRpProductchangeinfo selectTRpProductchangeinfoById(Long ID);

    /**
     * 查询机种切换管理列表
     * 
     * @param tRpProductchangeinfo 机种切换管理
     * @return 机种切换管理集合
     */
    public List<TRpProductchangeinfo> selectTRpProductchangeinfoList(TRpProductchangeinfo tRpProductchangeinfo);

    /**
     * 新增机种切换管理
     * 
     * @param tRpProductchangeinfo 机种切换管理
     * @return 结果
     */
    public int insertTRpProductchangeinfo(TRpProductchangeinfo tRpProductchangeinfo);

    /**
     * 修改机种切换管理
     * 
     * @param tRpProductchangeinfo 机种切换管理
     * @return 结果
     */
    public int updateTRpProductchangeinfo(TRpProductchangeinfo tRpProductchangeinfo);

    /**
     * 批量删除机种切换管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTRpProductchangeinfoByIds(String ids);

    /**
     * 删除机种切换管理信息
     * 
     * @param ID 机种切换管理ID
     * @return 结果
     */
    public int deleteTRpProductchangeinfoById(Long ID);
}
